Smartglass Message Types
========================

Submodules
----------

.. toctree::

   xbox.sg.packet.message
   xbox.sg.packet.simple

Module contents
---------------

.. automodule:: xbox.sg.packet
    :members:
    :undoc-members:
    :show-inheritance:
